@@ -72,8 +72,7 @@ pub const SPEED_PENALTY_PER_UNIT_STORAGE: f32 = 1.0 / 6_000.0; // 6_000 storage
 
 pub const LANDING_TIME_OVERHEAD: Tick = 10 * MINUTES;
 
-pub const QUICK_EXPLORATION_TIME: Tick = 1 * HOURS;
-pub const LONG_EXPLORATION_TIME: Tick = 8 * QUICK_EXPLORATION_TIME;
+pub const EXPLORATION_DURATION: Tick = 8 * HOURS;
 pub const ASTEROID_DISCOVERY_PROBABILITY: f64 = 0.15;
 pub const PORTAL_DISCOVERY_PROBABILITY: f64 = 0.05;
 
@@ -139,13 +138,13 @@ impl ReputationModifier {
 pub const MORALE_DECREASE_PER_LONG_TICK: f32 = MoraleModifier::MEDIUM_MALUS;
 pub const MORALE_INCREASE_PER_GAME: f32 = MoraleModifier::SEVERE_BONUS;
 pub const MORALE_RELEASE_MALUS: f32 = MoraleModifier::MEDIUM_MALUS;
-pub const MORALE_THRESHOLD_FOR_LEAVING: f32 = 2.0;
+pub const MORALE_THRESHOLD_FOR_LEAVING: f32 = MoraleModifier::HIGH_BONUS;
 pub const LEAVING_PROBABILITY_MORALE_MODIFIER: f64 =
     0.015 * (1.0 / MORALE_THRESHOLD_FOR_LEAVING) as f64;
 pub const MORALE_DEMOTION_MALUS: f32 = MoraleModifier::MEDIUM_MALUS;
 pub const MORALE_GAME_POPULATION_MODIFIER: f32 = 0.5;
 pub const MORALE_DRINK_BONUS: f32 = MoraleModifier::SEVERE_BONUS;
-pub const MORALE_HIRE_BONUS: f32 = MoraleModifier::SMALL_BONUS;
+pub const MORALE_HIRE_BONUS: f32 = MORALE_THRESHOLD_FOR_LEAVING;
 pub const TIREDNESS_DRINK_MALUS: f32 = TirednessCost::SEVERE;
 pub const TIREDNESS_DRINK_MALUS_SPUGNA: f32 = TirednessCost::HIGH;
 pub const TRAIT_PROBABILITY: f64 = 0.25;
