@@ -207,6 +207,10 @@ impl Team {
         self.spaceship.fuel_capacity()
     }
 
+    pub fn available_fuel_capacity(&self) -> u32 {
+        self.fuel_capacity() - self.used_fuel_capacity()
+    }
+
     pub fn used_storage_capacity(&self) -> u32 {
         self.resources.used_storage_capacity()
     }
@@ -215,6 +219,10 @@ impl Team {
         self.spaceship.storage_capacity()
     }
 
+    pub fn available_storage_capacity(&self) -> u32 {
+        self.storage_capacity() - self.used_storage_capacity()
+    }
+
     pub fn spaceship_speed(&self) -> f32 {
         self.spaceship.speed(self.used_storage_capacity())
     }
